@@ -39,21 +39,6 @@ void fail(void) { exit(2); }
 #  define INCLUDE_DEBUG_MSGS
 #endif
 
-/* Get program name. */
-static inline
-char const * msg_get_progname (void)
-{
-	extern char progname[];
-	return progname;
-}
-
-static inline
-void record_error(void)
-{
-	extern bool errors;
-	errors = 1;
-}
-
 inline static int
 do_msg(int severity)
 {
@@ -69,19 +54,34 @@ do_msg(int severity)
   return severity >= loglevel;
 }
 
+inline static char const *
+get_progname(void)
+{
+	extern char progname [];
+	return progname;
+}
+
+static inline
+void record_error(void)
+{
+	extern bool errors;
+	errors = 1;
+}
+
 inline static void
 line_message (int severity, const char * s, const char * fname, int line)
 {
-	char const * progname = msg_get_progname();
 	if (do_msg(severity)) {
       
 		if (fname == 0) {
-			fprintf (stderr,  "%s: %s.\n", progname, s);
+			fprintf (stderr,  "%s: %s.\n", get_progname(), s);
 		} else {
 			if (line > 0) {
-				fprintf (stderr, "%s: %s: %i: %s.\n", progname, fname, line, s);
+				fprintf (stderr, "%s: %s: %i: %s.\n",
+					 get_progname(), fname, line, s);
 			} else {
-				fprintf (stderr, "%s: %s: %s.\n", progname, fname, s);
+				fprintf (stderr, "%s: %s: %s.\n", 
+					 get_progname(), fname, s);
 			}
 		}
 		if (severity >= L_IMPORTANT) record_error();
@@ -151,6 +151,4 @@ bool errors_reported(void)
 	return errors;
 }
 
-
-
 #endif /* MSG_H__ */
